use sdl2::render::Canvas;
use sdl2::video::Window;

use crate::physics::PhysBody;
use crate::physics::PhysVec;
use crate::Camera;
use crate::Drawable;
use crate::ShipKind;
use crate::SpriteAtlas;

pub struct Ship {
	pub body: PhysBody,
	kind: ShipKind,
}

impl Ship {
	pub fn new(kind: ShipKind) -> Self {
		Ship {
			body: PhysBody::new(),
			kind,
		}
	}
}

impl Drawable for Ship {
	fn position(&self) -> PhysVec {
		return self.body.pos;
	}

	fn draw(
		&self,
		canvas: &mut Canvas<Window>,
		sa: &SpriteAtlas,
		c: &Camera,
	) -> Result<(), String> {
		let pos = self.screen_position(canvas, c);
		let sprite = sa.get(self.kind.sprite());
		sprite.draw(canvas, pos, self.body.angle.to_degrees())?;
		return Ok(());
	}
}
